==> KleckFiles(5.80.00).zip: KleckFiles/wiki/page/notebook/movies.js <==
var wikiMetaData = {created:'230826', modified:'230826'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>A System of Control</h1>",
"<p class='_w_glossary'>The ((serpent|serpent race)) program and mock the sheep through media, books, movies &amp; TV. Satan sings 'I writes the Songs that make the whole world sing', provides the scripts for the Simpsons, and produces pandemic movies to frontload the minds of the population before the event.",
"He's the master of psyop because he has an 'undercover demon agent' lurking within each unconverted host body. A hive-mind system of control. Like in the Matrix he can take control of anyone he wants.",
"</p>",
"<p>As Jonnie has proven, the devil sits in the seat of elohim. An imposter, posing as God.",	
"<div class='_w_videoThumbs'>230715</div>",
"</p>",	
	
"<p>Movies of truth, but subtily inverted, a slight bend here, a minor twist here. The bad guys are the good guys. The good guys are framed to look bad. Lying, fornicating, perversions are normalized. The real God, our Father in heaven and His son Jesus Christ get no air-time or are bent into subtle lies.",
"Actors are allowed to be perverted and lie. To keep the lost sheep asleep. Inverted by fantasy presented as light uplifting stories supported by wonderful music, and emotionally performances. Serpents glory in this stuff.",
"The 'The Matrix' and 'They Live' they flaunt the truth right out in the open. If anyone gets too clued-in they flood the system with alternate 'facts'. ",
"Like Jonathan posting covid-19 was Abaddon-Sheep-Slaughter. As this caught on they immediately started white-washing the Internet of latin word Ovid meaning sheep, as well as mobilizing the Fact-Checker army.",
"On big psyops like 911 Twin Towers, they give people hope-ium in the form of staged investigations. Show trials and romours of arrests that go no where. Like Trump's U.S. attorney general William Barr -- Promising to improve things. When things got too hot he suddenly gets moved sideways out of public view. ENDS-IN-NOTHING or someone is designated to take the fall. ",
"False-flag events to trumatise, polarize and control the population. Give up your guns. Don't speak up. Live in fear. Paid serpent actors create the illusion while the inocent pay the cost.",
"</p>",
"<p>So moving along. Praise God for Jonathan Kleck and what the Lord taught him. Now all the movies, TV, songs, even poetry - everything now makes sense.. Including (thank God) the Bible. Peter's keys unlock the mystery of everything. Those converted in Christ will understand that I am not exaggerating.",
"Also Jonathan is taught by the Holy Spirit. He's not solving these mysteries by himself. Many times I've had uncanny supernatural confirmations that prove that Jonathan is hearing 100% from the Lord God.",	
"</p>",

"<p class='_w_bibleVerse tabStop1'>Pro 25:2|It is the gloryH3519 of GodH430 to concealH5641 a thing:H1697 but the honourH3519 of kingsH4428(royality) is to search outH2713 a matter.H1697",
"</p>",
	
"<p class='_w_bibleVerse tabStop1'>Isa 5:20  WoeH1945 unto them that callH559 evilH7451 good,H2896 and goodH2896 evil;H7451 that putH7760 darknessH2822 for light,H216 and lightH216 for darkness;H2822 that putH7760 bitterH4751 for sweet,H4966 and sweetH4966 for bitter!H4751",
"</p>",	
	
"<p class='_w_bibleVerse tabStop1'>Rev 21:8|ButG1161 the fearful,G1169 andG2532 unbelieving,G571 andG2532 the abominable,G948 andG2532 murderers,G5406 andG2532 whoremongers,G4205 andG2532 sorcerers,G5332 andG2532 idolaters,G1496 andG2532 allG3956 liars,G5571 shall have theirG848 partG3313 inG1722 theG3588 lakeG3041 which burnethG2545 with fireG4442 andG2532 brimstone:G2303 which isG3603 the secondG1208 death.G2288",
"</p>",
	
"<p class='_w_hideStrongs _w_glossary'>((@strongs|Show Strongs))</p>",
	
"<h2>Thor: Ragnarok (2017)</h2>",
"<p>Hela says : \"want to see what real power really looks like?\" ... She then falls 'backwards' \"upside down\" into the deep dark.</p>",
"<p class='_w_glossary'>Upside down is all the serpent race have going for them. It's in all the movies. Once you understand their '((magic))' they are naked and you can see them.</p>",
	
'<iframe width="560" height="315" src="https://www.youtube.com/embed/4ah6kyMOjbQ?si=7_UjBiHrzv-Sxx_u" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>',
	
"<h2>Slumberland (2022)</h2>",
"<p>Nemo grows up in a light house (house of light) with her \"father\". ",
"She is separated from Father and must navigate slumberland to find the pearls of great value to see her father again.",
"The pearls are in the \"upside down\" deep dark area called the sea of nightmares.</p>" ,

"<p>Nemo also helps her fathers brother 'Philip' to become whole again.",
"She uses a pearl to wake up Philip's spirit 'twin' named \"Flip\" trapped in slumberland with amnesia.",
"</p>",



""
];

==> KleckFiles(6.39.00).zip: KleckFiles/wiki/page/notebook/movies.js <==
var wikiMetaData = {created:'230826', modified:'230826'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>A System of Control</h1>",
"<p class='_w_glossary'>The ((serpent|serpent race)) program and mock the sheep through media, books, movies &amp; TV. Satan sings 'I writes the Songs that make the whole world sing', provides the scripts for the Simpsons, and produces pandemic movies to frontload the minds of the population before the event.",
"He's the master of psyop because he has an 'undercover demon agent' lurking within each unconverted host body. A hive-mind system of control. Like in the Matrix he can take control of anyone he wants.",
"</p>",
"<p>As Jonnie has proven, the devil sits in the seat of elohim. An imposter, posing as God.",	
"<div class='_w_videoThumbs'>230715</div>",
"</p>",	
	
//"<p class='_w_hideStrongs _w_glossary'>((@strongs|Show Strongs))</p>",
	
"<h2>Thor: Ragnarok (2017)</h2>",
"<p>Hela says : \"want to see what real power really looks like?\" ... She then falls 'backwards' \"upside down\" into the deep dark.</p>",
"<p class='_w_glossary'>Upside down is all the serpent race have going for them. It's in all the movies. Once you understand their '((magic))' they are naked and you can see them.</p>",
	
'<iframe width="560" height="315" src="https://www.youtube.com/embed/4ah6kyMOjbQ?si=7_UjBiHrzv-Sxx_u" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>',
	
"<h2>Slumberland (2022)</h2>",
"<p>Nemo grows up in a light house (house of light) with her \"father\". ",
"She is separated from Father and must navigate slumberland to find the pearls of great value to see her father again.",
"The pearls are in the \"upside down\" deep dark area called the sea of nightmares.</p>" ,

"<p>Nemo also helps her fathers brother 'Philip' to become whole again.",
"She uses a pearl to wake up Philip's spirit 'twin' named \"Flip\" trapped in slumberland with amnesia.",
"</p>",



""
];
